/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.models.spi;

import org.apache.sling.models.annotations.ViaProviderType;

/**
 * SPI interface for providers of the @Via annotation.
 */
public interface ViaProvider {

    /**
     * Return the marker class for use in the @Via annotation
     *
     * @return the marker class
     */
    Class<? extends ViaProviderType> getType();

    /**
     * Get an adaptable using the value of the @Via annotation.
     *
     * @param original the original adaptable
     * @param value the value of the @Via annotation
     * @return the projected adaptable
     */
    Object getAdaptable(Object original, String value);

    /**
     * Marker object indicating that the original object should be used.
     */
    Object ORIGINAL = new Object();
}
